unit fRSAtest;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, RSA, ExtCtrls;

type
  TfrmRSATest = class(TForm)
    RSA1:          TRSA;
    btnCreateKey:  TButton;
    btnEncrypt:    TButton;
    edtPublicKey:  TEdit;
    edtPrivateKey: TEdit;
    sbStatus:      TStatusBar;
    edtTestText:   TEdit;
    btnDecrypt:    TButton;
    grpKeyLength:  TGroupBox;
    rbn512:        TRadioButton;
    rbn1024:       TRadioButton;
    rbn2048:       TRadioButton;
    rbn4096:       TRadioButton;
    lblPrivateKey: TLabel;
    lblPublicKey:  TLabel;
    lblTestText:   TLabel;
    btnPublicKeySet: TButton;
    btnPrivateKeySet: TButton;
    procedure      btnCreateKeyClick(Sender: TObject);
    procedure      RSA1StatusUpdate(Sender: TObject);
    procedure      rbn512Click(Sender: TObject);
    procedure      rbn1024Click(Sender: TObject);
    procedure      rbn2048Click(Sender: TObject);
    procedure      btnEncryptClick(Sender: TObject);
    procedure      btnDecryptClick(Sender: TObject);
    procedure rbn4096Click(Sender: TObject);
    procedure btnPublicKeySetClick(Sender: TObject);
    procedure btnPrivateKeySetClick(Sender: TObject);
  end;

var
  frmRSATest: TfrmRSATest;

implementation

{$R *.DFM}

{*******************************************************************************
* Procedure : TfrmRSATest.btnCreateKeyClick                                    *
********************************************************************************
* Purpose   : Calls the TRSA procedure for making key pairs using the currently*
*             selected key length                                              *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.btnCreateKeyClick(Sender: TObject);
begin
     // create the key pair
     RSA1.MakeKeyPair;

     // show the user the values
     edtPublicKey.Text := RSA1.PublicKey;
     edtPrivateKey.Text := RSA1.PrivateKey;
end; {TfrmRSATest.btnCreateKeyClick}

{*******************************************************************************
* Procedure : TfrmRSATest.btnEncryptClick                                      *
********************************************************************************
* Purpose   : Calls the TRSA procedure for encrypting data using the currently *
*             loaded keys                                                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.btnEncryptClick(Sender: TObject);
var
     TempString: string;
begin
     // encrypt the string in the edit box
     RSA1.EncryptString(edtTestText.Text, TempString);

     // copy the output back into the edit box
     edtTestText.Text := TempString;
end; {TfrmRSATest.btnEncryptClick}

{*******************************************************************************
* Procedure : TfrmRSATest.btnDecryptClick                                      *
********************************************************************************
* Purpose   : Calls the TRSA procedure for decrypting data using the currently *
*             loaded keys                                                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.btnDecryptClick(Sender: TObject);
var
     TempString: string;
begin
     // decrypt the string in the edit box
     RSA1.DecryptString(edtTestText.Text, TempString);

     // copy the output back into the edit box
     edtTestText.Text := TempString;
end; {TfrmRSATest.btnDecryptClick}

{*******************************************************************************
* Procedure : TfrmRSATest.RSA1StatusUpdate                                     *
********************************************************************************
* Purpose   : Passes the status messages fromTRSA to the status bar on the     *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.RSA1StatusUpdate(Sender: TObject);
begin
     sbStatus.SimpleText := RSA1.Status;
end; {RSA1StatusUpdate}

{*******************************************************************************
* Procedure : TfrmRSATest.rbn0512Click                                         *
********************************************************************************
* Purpose   : Sets the current key length of TRSA to 512 bits                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.rbn512Click(Sender: TObject);
begin
     RSA1.KeyBits := kb0512;
end;

{*******************************************************************************
* Procedure : TfrmRSATest.rbn1024Click                                         *
********************************************************************************
* Purpose   : Sets the current key length of TRSA to 1024 bits                 *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.rbn1024Click(Sender: TObject);
begin
     RSA1.KeyBits := kb1024;
end;

{*******************************************************************************
* Procedure : TfrmRSATest.rbn2048Click                                         *
********************************************************************************
* Purpose   : Sets the current key length of TRSA to 2048 bits                 *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.rbn2048Click(Sender: TObject);
begin
     // not yet available
     {RSA1.KeyBits := kb2048;}
end;

{*******************************************************************************
* Procedure : TfrmRSATest.rbn4096Click                                         *
********************************************************************************
* Purpose   : Sets the current key length of TRSA to 4096 bits                 *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRSATest.rbn4096Click(Sender: TObject);
begin
     // not yet available
     {RSA1.KeyBits := kb4096;}
end;

procedure TfrmRSATest.btnPublicKeySetClick(Sender: TObject);
begin
     RSA1.PublicKey := edtPublicKey.Text;
end;

procedure TfrmRSATest.btnPrivateKeySetClick(Sender: TObject);
begin
     RSA1.PrivateKey := edtPrivateKey.Text;
end;

end.
